/*
qlock
Copyright (C) 2005  Alexandru Lazar

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

You may contact me, Alexandru Lazar, the author of this program, by e-mail
on std@cwazy.co.uk or alexandru.lazar@gmail.com . Or, you may also contact me
by paper mail: Ritmului 12, Bl. 433, et. 6, ap.27, Bucuresti/Bucharest, 
Sector 2, Romania.
*/
#include <QtGui>
#include "digitalclock.h"

DigitalClock::DigitalClock(QWidget *parent)
    : QLCDNumber(parent)
{
    setSegmentStyle(Filled);

    QTimer *timer = new QTimer(this);
    connect(timer, SIGNAL(timeout()), this, SLOT(showTime()));
	showTime();
    timer->start(1000);


    setWindowTitle(tr("Qlock"));
    resize(150, 60);

	rang = false;
    rightClickMenu = new QMenu(this);
    configureProgramAction = rightClickMenu->addAction(QString("Configure program"),this,SLOT(ConfigureProgram()),0);
    configureAlarmAction = rightClickMenu->addAction(QString("Configure alarm"),this,SLOT(ConfigureAlarm()),0);
	rightClickMenu->addAction(QString("Shut up"),this,SLOT(ShutUp()),0);
ctype = twelve;
alarm = new Alarm((qobject_cast<QObject *>(this)),QTime::QTime(1,21,0),QDate::currentDate());
}

void DigitalClock::showTime()
{
    QTime time = QTime::currentTime();
    QString text = "";
if (ctype == twentyfour) {
	text = time.toString("hh:mm");
    if ((time.second() % 2) == 0)
        text[2] = ' ';
    display(text);
	}
else {
//This one's a bit more tricky due to QTimer brain damage. Since QTimer only knows about 24-hour format,
//can't output anything else and I'm not willing to use system-dependent functions for portability's sake
//we end up with the following idiosincratic thing:
	if ( time.hour() > 12 ) {
		QTime displayed_time = QTime( (time.hour() - 12), time.minute(), time.second());
		text = displayed_time.toString("h:m");
		display(text);
		}
	else {
	text = time.toString("hh:mm");
		if ((time.second() % 2) == 0)
        text[2] = ' ';
    display(text);
		}
	}
	if(!rang) {
		rang = alarm->ShouldRing();
	}
}

void DigitalClock::mousePressEvent(QMouseEvent *event) {
if(event->button() == Qt::RightButton) {
    rightClickMenu->exec(QCursor::pos());
  }
}

void DigitalClock::ConfigureProgram() {
    ProgConf *dialog = new ProgConf(this);
    dialog->exec();
}

void DigitalClock::ConfigureAlarm() {
	AlarmConf *dialog = new AlarmConf(this);
	dialog->exec();
}

void DigitalClock::SetClocktype(clocktype tp) {
	ctype = tp;
}

void DigitalClock::SetRingdate(QDate date) {
	ringdate = date;
	alarm->SetRingdate(ringdate);
}

void DigitalClock::SetRingtime(QTime time) {
	ringtime = time;
	alarm->SetRingtime(ringtime);
	}	

void DigitalClock::Reset() {
	rang=false;
	}
	
void DigitalClock::SetShouldMakeSounds(bool should) {
	alarm->SetShouldMakeSound(should);
	}
	
void DigitalClock::SetSound(QString sound) {
	alarm->SetSound(sound);
	}
	
void DigitalClock::SetShouldPopup(bool should) {
	alarm->SetShouldPopup(should);
	}

void DigitalClock::SetPopupMessage(QString message) {
	alarm->SetPopupMessage(message);
	}

void DigitalClock::SetShouldRun(bool should) {
	alarm->SetShouldRun(should);
}

void DigitalClock::SetCommand(QString command) {
	alarm->SetCommand(command);
}

void DigitalClock::SetPlaytimes (int times) {
	alarm->SetPlaytimes(times);
	}

void DigitalClock::ShutUp() {
	alarm->SetPlaytimes(0);
}

void DigitalClock::SetPlayMethod(playmethod method) {
	alarm->SetPlayMethod(method);
}

void DigitalClock::SetRingCommand(QString command) {
	alarm->SetRingCommand(command);
}
